@@ -18,7 +18,7 @@ class GenerateCalibratedData(ScienceTaskL0ToL1Base):
                 tags=[Tag.calibrated(), Tag.frame(), Tag.stokes("I")],
             )
 
-        movie_path = f"{self.dataset_id}_movie.mpg"
+        movie_path = f"{self.dataset_id}_movie.mp4"
         self.write(b"Movie", tags=[Tag.output(), Tag.movie()], relative_path=movie_path)
 
 
